/******************************************************************/
/* ACM ICPC 2012-2013                                             */
/* Northeastern European Regional Contest                         */
/* St Petersburg - Barnaul - Tashkent - Tbilisi, December 2, 2012 */
/******************************************************************/
/* Problem D. Disjoint Regular Expressions                        */
/*                                                                */
/* Original idea         Roman Elizarov                           */
/* Problem statement     Andrey Stankevich                        */
/* Test set              Andrey Stankevich                        */
/******************************************************************/
/* Solution                                                       */
/*                                                                */
/* Author                Petr Mitrichev                           */
/******************************************************************/

import java.util.List;
import java.io.IOException;
import java.io.OutputStreamWriter;
import java.util.Arrays;
import java.io.BufferedWriter;
import java.util.InputMismatchException;
import java.util.ArrayList;
import java.io.FileOutputStream;
import java.io.OutputStream;
import java.io.PrintWriter;
import java.io.FileInputStream;
import java.io.Writer;
import java.math.BigInteger;
import java.util.Collection;
import java.io.InputStream;

/**
 * Built using CHelper plug-in
 * Actual solution is at the top
 */
public class disjoint_petr {
	public static void main(String[] args) {
		InputStream inputStream;
		try {
			inputStream = new FileInputStream("disjoint.in");
		} catch (IOException e) {
			throw new RuntimeException(e);
		}
		OutputStream outputStream;
		try {
			outputStream = new FileOutputStream("disjoint.out");
		} catch (IOException e) {
			throw new RuntimeException(e);
		}
		InputReader in = new InputReader(inputStream);
		OutputWriter out = new OutputWriter(outputStream);
		Disjoint solver = new Disjoint();
		solver.solve(1, in, out);
		out.close();
	}
}

class Disjoint {
    static class State {
        State[] jump = new State[26];
        List<State> epsilonJumps = new ArrayList<State>();
        int id;
    }

    static class Automaton {
        List<State> states = new ArrayList<State>();
        State start;
        State finish;

        public static Automaton build(String regexp) {
            if (regexp.length() == 1) {
                return buildSingleLetter(regexp);
            }
            int[] balance = new int[regexp.length() + 1];
            for (int i = 0; i < regexp.length(); ++i) {
                balance[i + 1] = balance[i];
                if (regexp.charAt(i) == '(') ++balance[i + 1];
                if (regexp.charAt(i) == ')') --balance[i + 1];
            }
            int firstBreak = regexp.length();
            for (int i = 1; i < regexp.length(); ++i) if (balance[i] == 0) {
                firstBreak = i;
                break;
            }
            if (firstBreak == regexp.length()) {
                return build(regexp.substring(1, regexp.length() - 1));
            }
            firstBreak = regexp.length();
            for (int i = 1; i < regexp.length(); ++i) if (balance[i] == 0 && regexp.charAt(i) == '|') {
                firstBreak = i;
                break;
            }
            if (firstBreak < regexp.length()) {
                Automaton a = build(regexp.substring(0, firstBreak));
                Automaton b = build(regexp.substring(firstBreak + 1));
                return buildOr(a, b);
            }
            firstBreak = regexp.length();
            for (int i = 1; i < regexp.length(); ++i) if (balance[i] == 0 && regexp.charAt(i) != '*') {
                firstBreak = i;
                break;
            }
            if (firstBreak < regexp.length()) {
                Automaton a = build(regexp.substring(0, firstBreak));
                Automaton b = build(regexp.substring(firstBreak));
                return buildConcat(a, b);
            }
            if (!regexp.endsWith("*")) throw new RuntimeException();
            while (regexp.endsWith("*")) regexp = regexp.substring(0, regexp.length() - 1);
            return buildStar(build(regexp));
        }

        private static Automaton buildStar(Automaton a) {
            Automaton res = new Automaton();
            res.start = new State();
            res.finish = new State();
            res.start.epsilonJumps.add(res.finish);
            res.start.epsilonJumps.add(a.start);
            a.finish.epsilonJumps.add(res.start);
            res.states.add(res.start);
            res.states.add(res.finish);
            res.states.addAll(a.states);
            return res;
        }

        private static Automaton buildConcat(Automaton a, Automaton b) {
            Automaton res = new Automaton();
            a.finish.epsilonJumps.add(b.start);
            res.start = a.start;
            res.finish = b.finish;
            res.states.addAll(a.states);
            res.states.addAll(b.states);
            return res;
        }

        private static Automaton buildSingleLetter(String regexp) {
            Automaton res = new Automaton();
            res.start = new State();
            res.finish = new State();
            res.states.add(res.start);
            res.states.add(res.finish);
            res.start.jump[regexp.charAt(0) - 'a'] = res.finish;
            return res;
        }

        private static Automaton buildOr(Automaton a, Automaton b) {
            Automaton res = new Automaton();
            res.start = new State();
            res.start.epsilonJumps.add(a.start);
            res.start.epsilonJumps.add(b.start);
            res.finish = new State();
            a.finish.epsilonJumps.add(res.finish);
            b.finish.epsilonJumps.add(res.finish);
            res.states.add(res.start);
            res.states.add(res.finish);
            res.states.addAll(a.states);
            res.states.addAll(b.states);
            return res;
        }

        public static Automaton makeNonEmpty(Automaton a) {
            int index = 0;
            for (State x : a.states) x.id = index++;
            Automaton res = new Automaton();
            List<State> funny = new ArrayList<State>();
            for (int i = 0; i < a.states.size(); ++i) {
                State f = new State();
                funny.add(f);
            }
            for (int i = 0; i < a.states.size(); ++i) {
                State f = funny.get(i);
                for (int c = 0; c < 26; ++c)
                    f.jump[c] = a.states.get(i).jump[c];
                for (State x : a.states.get(i).epsilonJumps)
                    f.epsilonJumps.add(funny.get(x.id));
            }
            res.states.addAll(a.states);
            res.states.addAll(funny);
            res.start = funny.get(a.start.id);
            res.finish = a.finish;
            return res;
        }
    }

    static final int INF = (int) 1e9;

	public void solve(int testNumber, InputReader in, OutputWriter out) {
        String[] expr = new String[2];
        for (int i = 0; i < 2; ++i) {
            expr[i] = in.next();
        }
        Automaton[] au = new Automaton[2];
        for (int i = 0; i < 2; ++i) {
            au[i] = Automaton.makeNonEmpty(Automaton.build(expr[i]));
            int index = 0;
            for (State x : au[i].states) x.id = index++;
        }
        int[][] dist = new int[au[0].states.size()][au[1].states.size()];
        int[][] p0 = new int[au[0].states.size()][au[1].states.size()];
        int[][] p1 = new int[au[0].states.size()][au[1].states.size()];
        int[][] by = new int[au[0].states.size()][au[1].states.size()];
        for (int[] x : dist) Arrays.fill(x, INF);
        int[] q0 = new int[au[0].states.size() * au[1].states.size() * 2 + 2];
        int[] q1 = new int[au[0].states.size() * au[1].states.size() * 2 + 2];
        int qt = 0;
        int qh = 1;
        q0[qt] = au[0].start.id;
        q1[qt] = au[1].start.id;
        dist[au[0].start.id][au[1].start.id] = 0;
        while (qt != qh) {
            State s0 = au[0].states.get(q0[qt]);
            State s1 = au[1].states.get(q1[qt]);
            ++qt;
            if (qt >= q0.length) qt = 0;
            int curd = dist[s0.id][s1.id];
            for (State s : s0.epsilonJumps) {
                int newd = curd;
                int n0 = s.id;
                int n1 = s1.id;
                if (newd < dist[n0][n1]) {
                    dist[n0][n1] = newd;
                    p0[n0][n1] = s0.id;
                    p1[n0][n1] = s1.id;
                    by[n0][n1] = 1;
                    --qt;
                    if (qt < 0) qt = q0.length - 1;
                    q0[qt] = n0;
                    q1[qt] = n1;
                }
            }
            for (State s : s1.epsilonJumps) {
                int newd = curd;
                int n0 = s0.id;
                int n1 = s.id;
                if (newd < dist[n0][n1]) {
                    dist[n0][n1] = newd;
                    p0[n0][n1] = s0.id;
                    p1[n0][n1] = s1.id;
                    by[n0][n1] = 1;
                    --qt;
                    if (qt < 0) qt = q0.length - 1;
                    q0[qt] = n0;
                    q1[qt] = n1;
                }
            }
            for (int ch = 0; ch < 26; ++ch) {
                State ns0 = s0.jump[ch];
                State ns1 = s1.jump[ch];
                if (ns0 != null && ns1 != null) {
                    int newd = curd + 1;
                    int n0 = ns0.id;
                    int n1 = ns1.id;
                    if (newd < dist[n0][n1]) {
                        dist[n0][n1] = newd;
                        p0[n0][n1] = s0.id;
                        p1[n0][n1] = s1.id;
                        by[n0][n1] = 2 + ch;
                        q0[qh] = n0;
                        q1[qh] = n1;
                        ++qh;
                        if (qh >= q0.length) qh = 0;
                    }
                }
            }
        }
        State t0 = au[0].finish;
        State t1 = au[1].finish;
        if (dist[t0.id][t1.id] < INF) {
            out.printLine("Wrong");
            StringBuilder res = new StringBuilder();
            while (t0 != au[0].start || t1 != au[1].start) {
                int byy = by[t0.id][t1.id];
                if (byy == 1) {

                } else if (byy >= 2 && byy <= 27) {
                    res.append((char) ('a' + byy - 2));
                } else throw new RuntimeException();
                State nt0 = au[0].states.get(p0[t0.id][t1.id]);
                t1 = au[1].states.get(p1[t0.id][t1.id]);
                t0 = nt0;
            }
            res.reverse();
            out.printLine(res);
        } else {
            out.printLine("Correct");
        }
    }
}

class InputReader {

	private InputStream stream;
	private byte[] buf = new byte[1024];
	private int curChar;
	private int numChars;
	private SpaceCharFilter filter;

	public InputReader(InputStream stream) {
		this.stream = stream;
	}

	public int read() {
		if (numChars == -1)
			throw new InputMismatchException();
		if (curChar >= numChars) {
			curChar = 0;
			try {
				numChars = stream.read(buf);
			} catch (IOException e) {
				throw new InputMismatchException();
			}
			if (numChars <= 0)
				return -1;
		}
		return buf[curChar++];
	}

	public String readString() {
		int c = read();
		while (isSpaceChar(c))
			c = read();
		StringBuilder res = new StringBuilder();
		do {
			res.appendCodePoint(c);
			c = read();
		} while (!isSpaceChar(c));
		return res.toString();
	}

	public boolean isSpaceChar(int c) {
		if (filter != null)
			return filter.isSpaceChar(c);
		return c == ' ' || c == '\n' || c == '\r' || c == '\t' || c == -1;
	}

	public String next() {
		return readString();
	}

	public interface SpaceCharFilter {
		public boolean isSpaceChar(int ch);
	}
}

class OutputWriter {
	private final PrintWriter writer;

	public OutputWriter(OutputStream outputStream) {
		writer = new PrintWriter(new BufferedWriter(new OutputStreamWriter(outputStream)));
	}

	public OutputWriter(Writer writer) {
		this.writer = new PrintWriter(writer);
	}

	public void print(Object...objects) {
		for (int i = 0; i < objects.length; i++) {
			if (i != 0)
				writer.print(' ');
			writer.print(objects[i]);
		}
	}

	public void printLine(Object...objects) {
		print(objects);
		writer.println();
	}

	public void close() {
		writer.close();
	}

	}


