/******************************************************************/
/* ACM ICPC 2012-2013                                             */
/* Northeastern European Regional Contest                         */
/* St Petersburg - Barnaul - Tashkent - Tbilisi, December 2, 2012 */
/******************************************************************/
/* Problem F. Folding Snake Cube                                  */
/*                                                                */
/* Original idea         Roman Elizarov                           */
/* Problem statement     Roman Elizarov                           */
/* Test set              Roman Elizarov                           */
/******************************************************************/
/* Tests                                                          */
/*                                                                */
/* Author                Roman Elizarov                           */
/******************************************************************/

import java.io.File;
import java.io.FileWriter;
import java.io.IOException;
import java.io.PrintWriter;
import java.util.Arrays;
import java.util.Random;

/**
 * Tests generator for NEERC'2012 Problem F: Folding Snake Cube
 * @author Roman Elizarov
 */
public class Tests {
    private static int TEST_COUNTER = 0;
    private static final File TESTS_DIR = new File("tests");
    private static final File TESTS_LST = new File(TESTS_DIR, "tests.lst");

    private static final Random RND = new Random(20121117);

    private static final int N = 3;
    private static final int N3 = N * N * N;

    private static final int K = 15;

    private static final int[] DX = {1, -1, 0, 0 };
    private static final int[] DY = {0, 0, 1, -1 };

    private static final String[] SELECT_SEQS = {
            "STSTSTSTTTTSTSTTTSTTSTTTS sample found=6, visits=1580, solVisits=67",
            "STSTSTTTSTTTSTSTSTTSTSTST min solVisits=26, visits=4462",
            "STTSTTSTTSTTSTTSTTSTTSTTS palindrome min solVisits=26, visits=7618",
            "STSTTSTSTTSTSTSTTTTTTTTTT min visits/found=19, found=168, visits=3126, solVisits=150",
            "STSTSTSTSTSTSTTSTTSTTTTST min found=6, visits=620, solVisits=92",
            "STTSTTSTSTTSTSTTSTSTTSTTS palindrome min visits=2160",
            "TSTTSTSTSTTTSTTTSTSTSTTST palindrome non-corner-only min visits=7000",
            "TTTTSTSTTTTTTSTSTTTTTTSTS simple regular pattern (solves row by row) found=120, visits=86950, solVisits=723",
            "TTTTTTSTSTSTSTTTTTTTTTTTT max found=1004",
            "TTTTTTTTTTTTTTTTTTTTTTSTS max visits=2323622, found=372, max no of Ts",
            "TTTTTTTTTTTTTTTTTTTTSTSTS max-1 visits=2317640, found=858",
            "TTTTTTTTTTTTTTTTTTTSTTSTS max-2 visits=2250138, found=24",
            "TSTSTTSTSTSTSTSTSTSTTSTTS max no of Ss",
            "STTTTTTTTTTTTTTTTTTTTTSTS max visits=642192, found=264, when start with S",
            "STTTTTTTTTTTTTTTSTSTSTSTS max solVisits=380301, found=8",
            "TTTTTTTTTTTTSTTTSTSTSTSTS max-1 solVisits=376744, found=16",
            "TTTTTTTTSTTTTTTSTTTTSTSTS max-2 solVisits=348138, found=24",
            "STTTTTTTTTTTTTTTTTSTSTTTS max solVisits=55569 when found=6",
            "TTTTTTTTTTTTTTTSTTTTSTSTS max visits/found=248074 (max visits=1488442 when found=6)",
            "STTSTTTTTTTTTTTTTTTTTSTTS palindrome max solVistis-3=29250 (corner only start/end)",
            "TTSTTTTTSTTTTTTTSTTTTTSTT palindrome max solVistis-2=32920",
            "TTTTSTSTSTTTTTTTSTSTSTTTT palindrome max solVistis-1=33727",
            "TTSTSTTTTTTTTTTTTTTTSTSTT palindrome max solVistis=39284 (non-corner only start/end)",
            "TTTTTTTTTTSTSTSTTTTTTTTTT palindrome max visits-3=390082 ",
            "TTTTTTTTSTTTTTTTSTTTTTTTT palindrome max visits-2=587924",
            "STTTTTTTTTTTTTTTTTTTTTTTS palindrome max visits-1=641832",
            "TTTTSTTTTTTTTTTTTTTTSTTTT palindrome max visits=881606",
            "TTTTSTSTTTTTSTTTTTSTSTTTT palindrome max solVisits=3701, visits=87760, when found=6 (+corner-only sol)",
            "STTSTTTTTTTTSTTTTTTTTSTTS palindrome max visits=102786, solVisits=2888, when found=6 (+corner-only sol)",
            "TTTTSTSTSTTTSTTTSTSTSTTTT palindrome non-corner-only sol, found=8, visits=23038, solVisits=8477"
    };

    public static void main(String[] args) throws IOException {
        TESTS_DIR.mkdirs();
        TESTS_LST.delete();

        test("Sample").sample(
                "...............",
                "...............",
                "......Ff.......",
                ".....EeG.......",
                ".....d.gHh.....",
                "...CcD...Ii....",
                "...b......J....",
                ".AaB......jK...",
                "...........k...",
                "..........lL...",
                "........NmM....",
                "...............",
                "...............",
                "...............",
                "...............").write();

        for (String s : SELECT_SEQS) {
            int i = s.indexOf(' ');
            test(s.substring(i + 1)).seq(s.substring(0, i)).layoutAndWrite();
        }
    }

    private static Tests test(String description) {
        return new Tests(description);
    }

    // --- test instance ---

    private String description;
    private char[][] a = new char[K][K];
    private String seq;

    public Tests(String description) {
        this.description = description;
    }

    private Tests sample(String... s) {
        for (int x = 0; x < K; x++)
            a[x] = s[x].toCharArray();
        return this;
    }

    private Tests seq(String seq) {
        this.seq = seq;
        return this;
    }

    private void reverseSeq() {
        StringBuilder sb = new StringBuilder(seq);
        sb.reverse();
        seq = sb.toString();
        description = "[reversed] " + description;
    }

    private void layout() {
        for (int x = 0; x < K; x++)
            Arrays.fill(a[x], '.');
        int x = RND.nextInt(K);
        int y = RND.nextInt(K);
        a[x][y] = code(0);
        int d0 = RND.nextInt(4);
        for (int k = 0; k < 4; k++) {
            int dd = (d0 + k) % 4;
            if (tryLayout(x, y, dd, 0))
                return; // success
        }
        throw new IllegalStateException("this cannot happen");
    }

    private boolean tryLayout(int x, int y, int d, int i) {
        x += DX[d];
        y += DY[d];
        if (x < 0 || x >= K || y < 0 || y >= K)
            return false;
        if (a[x][y] != '.')
            return false;
        a[x][y] = code(i + 1);
        if (i >= seq.length())
            return true;
        switch (seq.charAt(i)) {
            case 'S':
                if (tryLayout(x, y, d, i + 1))
                    return true;
                break;
            case 'T':
                int d0 = RND.nextInt(4);
                for (int k = 0; k < 4; k++) {
                    int dd = (d0 + k) % 4;
                    if ((dd & ~1) != (d & ~1) && tryLayout(x, y, dd, i + 1))
                        return true;
                }
                break;
            default:
                throw new IllegalArgumentException(seq);
        }
        a[x][y] = '.';
        return false;
    }

    private char code(int i) {
        return i % 2 == 0 ? (char)(i / 2 + 'A') : (char)(i / 2 + 'a');
    }

    private void layoutAndWrite() throws IOException {
        layout();
        write();
        String oldSeq = seq;
        reverseSeq();
        if (seq.equals(oldSeq))
            return; // palindrome
        layout();
        write();
    }

    private void write() throws IOException {
        String tn = String.format("%02d", ++TEST_COUNTER);
        System.out.println(tn + " - " + description);
        PrintWriter lst = new PrintWriter(new FileWriter(TESTS_LST, true));
        lst.println(tn + " " + description);
        lst.close();
		PrintWriter out = new PrintWriter(new FileWriter(new File(TESTS_DIR, tn)));
        for (int x = 0; x < K; x++)
            out.println(new String(a[x]));
		out.close();
	}
}

