/******************************************************************/
/* ACM ICPC 2012-2013                                             */
/* Northeastern European Regional Contest                         */
/* St Petersburg - Barnaul - Tashkent - Tbilisi, December 2, 2012 */
/******************************************************************/
/* Problem H. Hyperdrome                                          */
/*                                                                */
/* Original idea         Vitaliy Aksenov                          */
/* Problem statement     Vitaliy Aksenov                          */
/* Test set              Vitaliy Aksenov                          */
/******************************************************************/
/* Solution                                                       */
/*                                                                */
/* Author                Roman Elizarov                           */
/******************************************************************/

import java.io.*;
import java.util.Arrays;

/**
 * Solution for NEERC'2012 Problem H: Hyperdrome
 * This solution checks correctness of the input.
 *
 * @author Roman Elizarov
 */
public class hyperdrome_re_merge_fast {

    private static final boolean DEBUG = false;

    public static void main(String[] args) throws Exception {
        new hyperdrome_re_merge_fast().go();
    }

    void go() throws Exception {
        read();
        solve();
        write();
    }

    int n;
    String s;

    void read() throws Exception {
        Scanner in = new Scanner(new File("hyperdrome.in"));
        n = in.nextInt();
        assert n >= 1 && n <= 300000;
        in.nextLine();
        s = in.next();
        assert s.length() == n;
        for (int i = 0; i < n; i++) {
            char c = s.charAt(i);
            assert c >= 'a' && c <= 'z' || c >= 'A' && c <= 'Z';
        }
        in.nextLine();
        in.close();
    }


    long[] masks;
    int[] counts;

    long result;

    void solve() {
        // compute all masks
        masks = new long[n + 1];
        long mask = 0L;
        for (int i = 0; i < n; i++) {
            char c = s.charAt(i);
            int j;
            if (c >= 'a' && c <= 'z')
                j = c - 'a';
            else if (c >= 'A' && c <= 'z')
                j = c - 'A' + 26;
            else
                throw new AssertionError();
            mask ^= 1L << j;
            masks[i] = mask;
        }
        // sort them
        Arrays.sort(masks);
        // fold & count each unique mask
        counts = new int[n + 1];
        int mc = 0;
        int cc = 1;
        for (int i = 1; i <= n; i++) {
            if (masks[i] == masks[mc]) {
                cc++;
            } else {
                counts[mc] = cc;
                masks[++mc] = masks[i];
                cc = 1;
            }
        }
        counts[mc++] = cc;
        // debug out
        if (DEBUG) {
            for (int i = 0; i < mc; i++)
                System.out.println(Long.toBinaryString(masks[i]) + ": " + counts[i]);
        }
        // compute results for even-lengths
        for (int i = 0; i < mc; i++)
            result += (long) counts[i] * (counts[i] - 1) / 2;
        // compute results for odd-lengths
        kloop:
        for (int k = 0; k < 2 * 26; k++) {
            long km = 1L << k;
            int i = 0;
            int j = 0;
            while (true) {
                if (j >= mc)
                    continue kloop;
                if ((masks[j] & km) != 0)
                    break;
                j++;
            }
            while (true) {
                while (true) {
                    if (i >= mc)
                        continue kloop;
                    if ((masks[i] & km) == 0 && masks[i] >= (masks[j] ^ km))
                        break;
                    i++;
                }
                while (true) {
                    if (j >= mc)
                        continue kloop;
                    if ((masks[j] & km) != 0 && (masks[j] ^ km) >= masks[i])
                        break;
                    j++;
                }
                if (masks[i] == (masks[j] ^ km)) {
                    result += (long) counts[i] * counts[j];
                    while (true) {
                        i++;
                        if (i >= mc)
                            continue kloop;
                        if ((masks[i] & km) == 0)
                            break;
                    }
                    while (true) {
                        j++;
                        if (j >= mc)
                            continue kloop;
                        if ((masks[j] & km) != 0)
                            break;
                    }
                }
            }
        }
    }

    void write() throws Exception {
        PrintWriter out = new PrintWriter("hyperdrome.out");
        out.println(result);
        out.close();
    }

//----------------- just for validation ------------------

    /**
     * Strict scanner to verify 100% correspondence between input files and input file format specification.
     * It is a drop-in replacement for {@link java.util.Scanner} that could be added to a solution source
     * (cut-and-paste) without breaking its ability to work with {@link java.util.Scanner}.
     */
    public class Scanner {
        private final BufferedReader in;
        private String line = "";
        private int pos;
        private int lineNo;

        public Scanner(File source) throws FileNotFoundException {
            in = new BufferedReader(new FileReader(source));
            nextLine();
        }

        public void close() {
            assert line == null : "Extra data at the end of file";
            try {
                in.close();
            } catch (IOException e) {
                throw new AssertionError("Failed to close with " + e);
            }
        }

        public void nextLine() {
            assert line != null : "EOF";
            assert pos == line.length() : "Extra characters on line " + lineNo;
            try {
                line = in.readLine();
            } catch (IOException e) {
                throw new AssertionError("Failed to read line with " + e);
            }
            pos = 0;
            lineNo++;
        }

        public String next() {
            assert line != null : "EOF";
            assert line.length() > 0 : "Empty line " + lineNo;
            if (pos == 0)
                assert line.charAt(0) > ' ' : "Line " + lineNo + " starts with whitespace";
            else {
                assert pos < line.length() : "Line " + lineNo + " is over";
                assert line.charAt(pos) == ' ' : "Wrong whitespace on line " + lineNo;
                pos++;
                assert pos < line.length() : "Line " + lineNo + " is over";
                assert line.charAt(pos) > ' ' : "Line " + lineNo + " has double whitespace";
            }
            StringBuilder sb = new StringBuilder();
            while (pos < line.length() && line.charAt(pos) > ' ')
                sb.append(line.charAt(pos++));
            return sb.toString();
        }

        public int nextInt() {
            String s = next();
            assert s.length() == 1 || s.charAt(0) != '0' : "Extra leading zero in number " + s + " on line " + lineNo;
            assert s.charAt(0) != '+' : "Extra leading '+' in number " + s + " on line " + lineNo;
            try {
                return Integer.parseInt(s);
            } catch (NumberFormatException e) {
                throw new AssertionError("Malformed number " + s + " on line " + lineNo);
            }
        }
    }
}

