/******************************************************************/
/* ACM ICPC 2012-2013                                             */
/* Northeastern European Regional Contest                         */
/* St Petersburg - Barnaul - Tashkent - Tbilisi, December 2, 2012 */
/******************************************************************/
/* Problem I. Identification of Protein                           */
/*                                                                */
/* Original idea         Mikhail Dvorkin                          */
/* Problem statement     Mikhail Dvorkin                          */
/* Test set              Mikhail Dvorkin                          */
/******************************************************************/
/* Solution                                                       */
/*                                                                */
/* Author                Georgiy Korneev                          */
/******************************************************************/

import java.io.*;
import java.util.*;

public class identification_gk {
    static Scanner in;
    static PrintWriter out;
    static final long P = 9705276;
    static final long Q = 12805858;

    Euclid euclid = euclid(P, Q);

    class Euclid {
        long p, q, d;

        Euclid(long p, long s, long d) {
            this.p = p;
            this.q = s;
            this.d = d;
        }
    }

    class Pair {
        int p, q;

        Pair(long mass) {
            long k = (Q - 1 - mass * euclid.p) / Q;
            this.p = (int) ((mass * euclid.p + k * Q) / euclid.d);
            this.q = (int) ((mass * euclid.q - k * P) / euclid.d);
        }
    }

    void run() {
        int n = in.nextInt();
        List<Long> masses = new ArrayList<>(n);
        for (int i = 0; i < n; i++) {
            masses.add(Math.round(in.nextDouble() * 1e5));
        }

        Pair max = new Pair(Collections.max(masses));
        int s = max.p + max.q;
        int h = s / 2 + 1;
        int[][] c = new int[h][h];
        for (Long mass : masses) {
            if (mass % euclid.d != 0) {
                continue;
            }
            Pair pair = new Pair(mass);
            int z = pair.p + pair.q;
            if (max.p < pair.p || pair.q < 0 || max.q < pair.q) {
                continue;
            }
            if (z < h) {
                c[z][pair.p]++;
            } else {
                c[s - z][max.p - pair.p]++;
            }
        }

        int[][][] a = new int[h][h][h];
        int[][][] pl = new int[h][h][h];
        int[][][] pr = new int[h][h][h];
        a[0][0][0] = c[0][0];
        for (int i = 1; i < h; i++) {
            for (int lp = 0; lp <= i; lp++) {
                for (int rp = 0; rp <= lp; rp++) {
                    for (int plp = Math.max(lp - 1, 0); plp <= lp; plp++) {
                        for (int prp = Math.max(rp - 1, 0); prp <= rp; prp++) {
                            if (a[i][lp][rp] < a[i - 1][plp][prp]) {
                                a[i][lp][rp] = a[i - 1][plp][prp];
                                pl[i][lp][rp] = plp;
                                pr[i][lp][rp] = prp;
                            }
                        }
                    }
                    a[i][lp][rp] += c[i][lp];
                    if (rp != lp) {
                        a[i][lp][rp] += c[i][rp];
                    }
                }
            }
        }
        int best = 0;
        int bestLP = 0;
        int bestRP = 0;
        {
            for (int lp = 0; lp < h; lp++) {
                for (int dp = 0; dp <= s % 2; dp++) {
                    int rp = max.p - lp - dp;
                    if (0 <= rp && rp < h) {
                        if (best < a[h - 1][lp][rp]) {
                            best = a[h - 1][lp][rp];
                            bestLP = lp;
                            bestRP = rp;
                        }
                    }
                }
            }
        }
        Deque<Boolean> deque = new ArrayDeque<>();
        int lp = bestLP;
        int rp = bestRP;
        if (s % 2 == 1) {
            deque.add(lp + rp != max.p);
        }
        for (int i = h - 1; i > 0; i--) {
            int plp = pl[i][lp][rp];
            int prp = pr[i][lp][rp];
            deque.addFirst(plp != lp);
            deque.addLast(prp != rp);
            lp = plp;
            rp = prp;
        }
        for (Boolean b : deque) {
            out.print(b ? "P" : "Q");
        }
        out.println();
    }

    private Euclid euclid(long a, long b) {
        if (a == 0) {
            long p = 0;
            long q = 1;
            assert a * p + b * q == b;
            return new Euclid(0, 1, b);
        }
        Euclid pair = euclid(b % a, a);
        return new Euclid(pair.q - pair.p * (b / a), pair.p, pair.d);
    }

    static class Scanner {
        final BufferedReader reader;
        StringTokenizer tokenizer = new StringTokenizer("");

        public Scanner(File file) throws FileNotFoundException {
            reader = new BufferedReader(new FileReader(file));
        }

        public int nextInt() {
            return Integer.parseInt(next());
        }

        public double nextDouble() {
            return Double.parseDouble(next());
        }

        public String next() {
            while (!tokenizer.hasMoreTokens()) {
                try {
                    tokenizer = new StringTokenizer(reader.readLine());
                } catch (IOException e) {
                    throw new AssertionError();
                }
            }
            return tokenizer.nextToken();
        }

        public void close() {
        }
    }


    public static void main(String[] args) throws Exception {
        in = new Scanner(new File("identification.in"));
        out = new PrintWriter("identification.out");

        new identification_gk().run();

        in.close();
        out.close();
    }
}

